package physbeans.editors;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.beans.*;
import physbeans.inout.*;
import physbeans.math.*;
import physbeans.event.*;

/**
 * The panel for the ArrayOfBooleanEditor.
 * <p>It shows the boolean values as a list of check boxes.
 */
public class ArrayOfBooleanCustomEditor extends JPanel {
  
  protected PropertyEditorSupport editor;
  protected SwitchBox switchBox;
  protected NumericTextField dimField;
  protected Font standardFont;
  
  protected final int cols = 12;   // size of text fields
  protected final int prec = 8;   // precision of text fields
  
  public ArrayOfBooleanCustomEditor(PropertyEditorSupport ed) {
    // get the old values
    editor = ed;
    boolean[] value = (boolean[]) editor.getValue();
    int dim = value.length;
    
    standardFont = new Font("Lucida Sans", Font.PLAIN, 11);
    setLayout(new BorderLayout());
    JPanel pHead = new JPanel();
    dimField = new NumericTextField(dim, 8, 4, "Dimension = ", "");
    dimField.setFont(standardFont);
    pHead.add(dimField);
    dimField.addPropertyChangeListener(new MyDimListener());
    
    // create panel with switchbox
    switchBox = new SwitchBox();
    switchBox.setTitle("");
    switchBox.setWithTwoColumns(true);
    JScrollPane scrollPane = new JScrollPane(switchBox,
        JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
        JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
    setBoxesToValue(value);
    switchBox.addSwitchListener(new MySwitchListener());
    
    add(pHead, BorderLayout.NORTH);
    add(scrollPane, BorderLayout.CENTER);
    setMaximumSize(new Dimension(280, 150));
  }
  
  /**
   * Called when a value of the switchbox is changed.
   */
  protected void changeValue() {
    boolean[] newValue = getValueFromBoxes();
    
    editor.setValue(newValue);
    editor.firePropertyChange();
  }
  
  /**
   * Called when the value of the dimension field is changed.
   */
  protected void resize() {
    int newDim = (int) Math.round(dimField.getValue());    
    if (newDim < 0) {
      newDim = switchBox.getCount();
    }
    
    if (newDim != switchBox.getCount()) {
      switchBox.setCount(newDim);
      validate();
      editor.setValue(switchBox.getSelected());
      editor.firePropertyChange();
    }
    
    dimField.setValueInternally(newDim);   // to fix fractional input
  }
  
  /**
   * Gets boolean array from the switchbox.
   */
  protected boolean[] getValueFromBoxes() {
    return switchBox.getSelected();
  }
  
  /**
   * Sets switchbox from boolean array.
   */
  protected void setBoxesToValue(boolean[] newVal) {
    switchBox.setSelected(newVal);    
    validate();
  }
  
  /**
   * Listeners to change in the text fields.
   */
  public class MySwitchListener implements SwitchListener {
    public void valueChanged(SwitchEvent e) {
      changeValue();
    }
  }
  
  /**
   * Listeners to change in the dimension field.
   */
  public class MyDimListener implements PropertyChangeListener {
    public void propertyChange(PropertyChangeEvent e) {
      resize();
    }
  }
  
}
