package physbeans.editors;

import java.awt.*;
import javax.swing.*;
import java.beans.*;
import physbeans.inout.*;

/**
 * The panel for the ArrayOfIntEditor.
 * <p>It shows a list of the array values and allows to change them and the size
 * of the vector.
 */
public class ArrayOfIntCustomEditor extends JPanel {
  
  protected PropertyEditorSupport editor;
  protected IntegerTextField[] textfield;
  protected IntegerTextField dimField;
  protected Box pList;
  protected Font standardFont;
  
  protected final int cols = 12;   // size of text fields
  protected final int prec = 8;   // precision of text fields
  
  public ArrayOfIntCustomEditor(PropertyEditorSupport ed) {
    // get the old values
    editor = ed;
    int[] value = (int[]) editor.getValue();
    int dim = value.length;
    
    // vertical list with values, on top box for dimension
    standardFont = new Font("Lucida Sans", Font.PLAIN, 11);
    setLayout(new BorderLayout());
    JPanel pHead = new JPanel();
    dimField = new IntegerTextField(dim, 8, 4, "Dimension = ", "");
    dimField.setFont(standardFont);
    pHead.add(dimField);
    dimField.addPropertyChangeListener(new MyDimListener());
    
    // create panel with text fields
    pList = new Box(BoxLayout.Y_AXIS);
    pList.setPreferredSize(new Dimension(260, dim*30+30));
    JScrollPane scrollPane = new JScrollPane(pList,
        JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
        JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
    textfield = new IntegerTextField[0];
    setTextFieldsToVector(value);
    
    add(pHead, BorderLayout.NORTH);
    add(scrollPane, BorderLayout.CENTER);
    setMaximumSize(new Dimension(280, 150));
  }
  
  /**
   * Called when the value of a textfield is changed.
   */
  protected void changeValue() {
    int[] newValue = getValueFromTextFields();
    
    editor.setValue(newValue);
    editor.firePropertyChange();
  }
  
  /**
   * Called when the value of the dimension field is changed.
   */
  protected void resize() {
    int newDim = dimField.getValueAsInt();
    
    if (newDim < 0) {
      newDim = textfield.length;
    }
    
    if (newDim != textfield.length) {
      int[] newValue = new int[newDim];
      setTextFieldsToVector(newValue);
      editor.setValue(newValue);
      editor.firePropertyChange();
    }
    
    dimField.setValueInternally(newDim);   // to fix faulty input
  }
  
  /**
   * Gets DVector from the text fields.
   */
  protected int[] getValueFromTextFields() {
    int dim = textfield.length;
    int[] newValues = new int[dim];
    
    for (int i = 0; i < dim; i++) {
      newValues[i] = textfield[i].getValueAsInt();
    }
    
    return newValues;
  }
  
  /**
   * Sets text fields from DVector.
   */
  protected void setTextFieldsToVector(int[] newVal) {
    int dim = newVal.length;
    
    if (textfield.length == dim) {
      for (int i = 0; i < dim; i++) {
        textfield[i].setValueInternally(newVal[i]);
      }
    } else {
      pList.removeAll();
      textfield = new IntegerTextField[dim];
      for (int i = 0; i < dim; i++) {
        textfield[i] = new IntegerTextField(newVal[i], cols, prec,
            "x(" + i + ") = ", "");
        textfield[i].setFont(standardFont);
        pList.add(textfield[i]);
        textfield[i].addPropertyChangeListener(new MyTextListener());
      }
      pList.setPreferredSize(new Dimension(260, dim*30+30));
    }
    validate();
  }
  
  /**
   * Listeners to change in the text fields.
   */
  public class MyTextListener implements PropertyChangeListener {
    public void propertyChange(PropertyChangeEvent e) {
      changeValue();
    }
  }
  
  /**
   * Listeners to change in the dimension field.
   */
  public class MyDimListener implements PropertyChangeListener {
    public void propertyChange(PropertyChangeEvent e) {
      resize();
    }
  }
  
}
