package physbeans.editors;

import java.util.*;
import java.awt.*;
import java.awt.geom.*;
import java.awt.font.*;
import java.beans.*;

/**
 * Property editor for int arrays
 */
public class ArrayOfIntEditor extends PropertyEditorSupport {

  /**
   * Returns a string that represents the current int array.
   */
  public String getAsText() {
    return null;

  /*
  if (getValue() == null)
  return "null";

  int[] v = (int[]) getValue();
  int dim = v.length;

  String result = "[";
  for (int i=0; i<dim-1; i++) {
  result += v[i] + ",";
  }
  result += v[dim-1] + "]";

  return result;
   */
  }

  /**
   * Reads the value of the property by parsing a string.
   */
  /*
  public void setAsText(String text) throws IllegalArgumentException {
    if (text.equals("null") || text.equals("")) {
      setValue(null);
      return;
    }

    int[] v = null;
    StringTokenizer toc = new StringTokenizer(text, "[] ,;");
    int dim = toc.countTokens();
    v = new int[dim];

    try {
      for (int i = 0; i < dim; i++) {
        v[i] = Integer.parseInt(toc.nextToken());
      }

    } catch (NumberFormatException e) {
      wrongFormat(text);
    }

    setValue(v);
  }
   */

  /**
   * Throws an exception if the text has a wrong format.
   */
  protected void wrongFormat(String text) throws IllegalArgumentException {
    throw new IllegalArgumentException("wrong format in " + text);
  }

  /**
   * Returns a string with java code that initializes a DVector.
   */
  public String getJavaInitializationString() {
    int[] v = (int[]) getValue();
    String result = "new int[]{";
    int dim = v.length;

    for (int i = 0; i < dim - 1; i++) {
      result += v[i] + ",";
    }
    result += v[dim - 1] + "}";

    return result;
  }

  /**
   * Returns true to show that the value is displayed graphically instead as text.
   * NetBeans can't cope with a custom editor + text simultaneously!
   */
  public boolean isPaintable() {
    return true;
  }

  /**
   * Draws a graphic representation.
   */
  public void paintValue(Graphics g, Rectangle box) {
    Graphics2D g2 = (Graphics2D) g;
    int[] values = (int[]) getValue();
    StringBuilder s = new StringBuilder();
    for (int i = 0; i < 3; i++) {
      if (values.length > i) {
        s.append(values[i]);
      }
      if (values.length > i + 1) {
        s.append(", ");
      }
    }
    if (values.length > 3) {
      s.append("...");
    }
    g2.setPaint(Color.white);
    g2.fill(box);
    g2.setPaint(Color.black);
    FontRenderContext context = g2.getFontRenderContext();
    Rectangle2D stringBounds = g2.getFont().getStringBounds(s.toString(), context);
    double w = stringBounds.getWidth();
    double x = box.x;
    if (w < box.width) {
      x += (box.width - w) / 2;
    }
    double ascent = -stringBounds.getY();
    double y = box.y + (box.height - stringBounds.getHeight()) / 2 + ascent;
    g2.drawString(s.toString(), (float) x, (float) y);
  }

  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }

  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new ArrayOfIntCustomEditor(this);
  }
}
