package physbeans.editors;

import java.util.*;
import java.awt.*;
import java.beans.*;
import physbeans.math.*;

/**
 * Property editor for DVector.
 */
public class PolynomialEditor extends PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current polynomial.
   */
  public String getAsText() {
    Polynomial v = (Polynomial) getValue();
    
    if (v == null) {
      return "null";
    } else {
      return v.getCoeff().toString();
    }
  }
  
  /**
   * Reads the value of the polynomial by parsing a string.
   */
  public void setAsText(String text) throws IllegalArgumentException {
    if (text.equals("null") || text.equals("")) {
      setValue(null);
      return;
    }
    
    setValue(new Polynomial(DVector.valueOf(text)));
  }
  
  /**
   * Returns a string with java code that initializes a DVector.
   */
  public String getJavaInitializationString() {
    Polynomial v = (Polynomial) getValue();
    int deg = v.getDegree();
    if (deg == -1) {
      return "new Polynomial()";
    }
    
    String result = "new Polynomial(new double[]{";
    
    for (int i=deg; i>0; i--) {
      result += v.getCoeff(i) + ",";
    }
    result += v.getCoeff(0) + "})";
    
    return result;
  }
    
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new PolynomialCustomEditor(this);
  }
  
}
