package physbeans.event;

import java.util.*;

/**
 * class to simplify use of SwitchEvents
 */
public class SwitchSupport {
  
  /** list of all observer objects listening to this SwitchBox */
  protected Vector<SwitchListener> listeners;
  
  /** Creates a new instance of SwitchSupport */
  public SwitchSupport() {
    // prepare for listeners
    listeners = new Vector<SwitchListener>();
  }
  
  /**
   * register a SwitchListener
   */
  public synchronized void addSwitchListener(SwitchListener sl) {
    listeners.addElement(sl);
  }
  
  /**
   * de-register a SwitchListener
   */
  public synchronized void removeSwitchListener(SwitchListener sl) {
    listeners.removeElement(sl);
  }
  
  /**
   * inform all SwitchListeners that the value of the control has changed
   */
  public void fireSwitchEvent(SwitchEvent e) {
    Vector l;
    
    // clone the list of listeners so that delivery and simultaneous
    // addition/deletion of listeners don't interfere
    synchronized (this) {
      l = (Vector) listeners.clone();
    }
    
    for (int i = 0; i < l.size(); i++) {
      ((SwitchListener) l.elementAt(i)).valueChanged(e);
    }
  }
}
