package physbeans.func;

import java.io.*;
import physbeans.math.*;
import static java.lang.Math.*;

/**
 * Applies a harmonic function (based on cosine) to its input vector.
 */
public class HarmonicFunction extends OneParameterFunction {
  
  protected double a;
  protected double alpha;
  protected double omega;
  protected double offset;
    
  /**
   * constructs a standard cosine
   */
  public HarmonicFunction() {
    super();
    a = 1.0;
    omega = 1.0;
    alpha = 0.0;
    offset = 0.0;
  }
   
  /**
   * Gets amplitude of the cosine.
   */
  public double getAmplitude() {
    return this.a;
  }
  
  /** 
   * Sets amplitude of the cosine.
   */
  public void setAmplitude(double a) {
    this.a = a;
    inform();
  }
  
  /** 
   * Gets phase shift of the cosine.
   */
  public double getAlpha() {
    return this.alpha;
  }
  
  /** 
   * Sets phase shift of the cosine.
   */
  public void setAlpha(double alpha) {
    this.alpha = alpha;
    inform();
  }
  
  /** 
   * Gets angular frequency of the cosine.
   */
  public double getOmega() {
    return this.omega;
  }
  
  /** 
    * Sets angular frequency of the cosine.
   */
  public void setOmega(double omega) {
    this.omega = omega;
    inform();
  }
  
  /**
   * Gets constant offset.
   */
  public double getOffset() {
    return this.offset;
  }
  
  /**
   * Sets constant offset.
   */
  public void setOffset(double offset) {
    this.offset = offset;
    inform();
  }
  
  /*
   * Computes the cosine value for one given value t.
   */
  public double evaluate(double t) {
    double x = a * cos(omega * t + alpha) + offset;
    return x;
  }
  
}
