package physbeans.func;

/**
 * Produces double vector with normally distributed random values
 * for given mean and standard deviation.
 */
public class NormalRandomVector extends RandomVector {

  protected double standardDeviation;
  protected double mean;

  /** Creates a new instance of NormalRandomVector */
  public NormalRandomVector() {
    super();
    mean = 0.0;
    standardDeviation = 1.0;

    compute();
  }
  
  /**
   * Computes one random number.
   * The input argument is ignored.
   */
  public double evaluate(double t) {
    return standardDeviation * rng.nextGaussian() + mean;
  }

  /**
   * Gets the mean of the normal distribution.
   */
  public double getMean() {
    return this.mean;
  }

  /**
   * Sets the mean of the normal distribution.
   */
  public void setMean(double mean) {
    this.mean = mean;
    trigger();
  }

  /**
   * Gets the standard deviation of the normal distribution.
   */
  public double getStandardDeviation() {
    return this.standardDeviation;
  }

  /**
   * Sets the standard deviation of the normal distribution.
   */
  public void setStandardDeviation(double standardDeviation) {
    this.standardDeviation = standardDeviation;
    trigger();
  }
}
