package physbeans.func;

import java.io.*;

/**
 * PiecewiseLinearFunction with a period T.
 * Corner points are defined for a basic period T=1, i.e. their x values have to
 * be in the interval [0, 1].
 */
public class PeriodicPiecewiseLinearFunction extends PiecewiseLinearFunction
implements Serializable {
  
  /** Holds value of property period. */
  protected double period;
  
  /** Creates a new instance of PeriodicPiecewiseLinearFunction */
  public PeriodicPiecewiseLinearFunction() {
    super();
    period = 1.0;
  }
  
  /**
   * Computes all function values using period.
   */
  public double evaluate(double t) {
    // reduce t to basic intervall [0, 1]
    t = t/period;
    t = t - Math.floor(t);
    
    return super.evaluate(t);
  }
  
  /**
   * Gets the period T.
   */
  public double getPeriod() {
    return this.period;
  }
  
  /**
   * Sets the period T.
   * Input parameter has to be positive.
   */
  public void setPeriod(double period) {
    this.period = period;
  }
}
