package physbeans.func;

import physbeans.math.*;
import physbeans.model.*;
import java.io.*;

/**
 * Periodic function describing a sine that is cut at a given phase.
 * External parameter is the phase angle.
 */
public class PhaseCutSineFunction extends OneParameterFunction implements Serializable, PeriodicFunctionWithParameter {
  
  protected double cutPhase;
  protected double T;
  protected double A;
  protected double phase;
  
  /** Creates a new instance of ImpulseFunction */
  public PhaseCutSineFunction() {
    super(-1);
    cutPhase = 0.5*Math.PI;
    T = 2*Math.PI;
    A = 1.0;
    phase = 0.0;
  }
  
  /**
   * Gets the cut phase.
   */
  public double getCutPhase() {
    return cutPhase;
  }
  
  /**
   * Sets the cut phase.
   */
  public void setCutPhase(double p) {
    cutPhase = p;
  }
  
  /**
   * Gets the period T.
   */
  public double getPeriod() {
    return T;
  }
  
  /**
   * Sets the period T.
   */
  public void setPeriod(double period) {
    T = period;
  }
  
  /**
   * Gets the parameter value.
   * It is given as relative value, between 0 and 1.
   */
  public double getParameter() {
    return cutPhase/2*Math.PI;
  }
  
  /**
   * Sets the parameter
   */
  public void setParameter(double p) {
    cutPhase = p*2*Math.PI;
  }
  
  /**
   * Gets amplitude of the pulse.
   */
  public double getAmplitude() {
    return A;
  }
  
  /**
   * Sets amplitude of the pulse.
   */
  public void setAmplitude(double amplitude) {
    A = amplitude;
  }
  
  /**
   * Gets the phase of the sine function.
   */
  public double getPhase() {
    return this.phase;
  }
  
  /**
   * Sets the phase of the sine function.
   */
  public void setPhase(double phase) {
    this.phase = phase;
  }
  
  /*
   * Computes the function value for one given value t.
   */
  public double evaluate(double t) {
    // reduce t to basic intervall [0, T]
    t = t - T*Math.floor(t/T);
    
    double x = 0.0;
    if (t >= cutPhase * T/(2* Math.PI)) {
      x = A*Math.sin(2*Math.PI*t/T + phase);
    }
    return x;
  }
  
}