package physbeans.func;

import physbeans.math.*;

/**
 * reduces input value to within a 2 pi wide interval.<br>
 * By default the interval is [-pi, pi), but it can be changed using
 * the max parameter.<P>
 * To simplify signal routing, it can work with an input vector: It changes
 *   some of the inputs and simply propagates the rest.
 */
public class ReducePhaseFunction extends OneParameterFunction {
  
  /** maximal value of the reduced angle */
  protected double max;
  
  /**
   * constructs a standard reduction function with one input parameter
   */
  public ReducePhaseFunction() {
    super(-1);
    max =  Math.PI;
  }
  
  /**
   * computes the reduced angle
   */
  public double evaluate(double phi) {
    phi -= 2*Math.PI*Math.floor(phi/(2*Math.PI));  // lies in [0, 2*pi)
    if (phi>= max) {
      phi -= 2*Math.PI;
    }
    return phi;
  }
  
  /**
   * gets maximal value of the reduced angle.<br>
   */
  public double getMax() {
    return max;
  }
  
  /**
   * sets maximal value of the reduced angle.<br>
   * minimal value is given by max - 2*pi
   */
  public void setMax(double m) {
    // only values in [0, 2*pi) are accepted
    if ((0 <= max) && (max < 2*Math.PI)) {
      max = m;
    }
    inform();
  }
  
}
