package physbeans.func;

/**
 * bean for the usual simple math functions.<br>
 * implements log, exp, ...     (
 */
public class SimpleMathFunction extends OneParameterFunction {
  
  // implemented functions
  public static final int SIN  = 0;
  public static final int COS  = 1;
  public static final int TAN  = 2;
  public static final int EXP  = 3;
  public static final int LOG  = 4;
  public static final int SQRT = 5;
  public static final int SQR  = 6;
  public static final int ABS  = 7;
  public static final int ASIN = 8;
  public static final int ACOS = 9;
  public static final int ATAN = 10;
  
  protected int functionType;
  
  /**
   * constructs a standard sine for one input
   */
  public SimpleMathFunction() {
    super(-1);
    functionType = SIN;
  }
  
  /**
   * computes the value of input i
   */
  public double evaluate(double t) {
    double result = 0.0;
    switch (functionType) {
      case SIN :
        result = Math.sin(t);
        break;
      case COS :
        result = Math.cos(t);
        break;
      case TAN :
        result = Math.tan(t);
        break;
      case EXP :
        result = Math.exp(t);
        break;
      case LOG :
        result = Math.log(t);
        break;
      case SQRT :
        result = Math.sqrt(t);
        break;
      case SQR :
        result = t*t;
        break;
      case ABS :
        result = Math.abs(t);
        break;
      case ASIN :
        result = Math.asin(t);
        break;
      case ACOS :
        result = Math.acos(t);
        break;
      case ATAN :
        result = Math.atan(t);
        break;
    }
    
    return result;
  }
  
  /**
   * get type of function
   */
  public int getFunctionType() {
    return this.functionType;
  }
  
  /**
   * set type of function
   */
  public void setFunctionType(int functionType) {
    this.functionType = functionType;
  }
  
}
