package physbeans.func;

import java.io.*;
import physbeans.func.GenericVectorFunction;
import physbeans.math.*;
import physbeans.event.*;

/**
 * Routes one of its input vectors to the output vector.<br>
 * The number of the selected input is usually set via a SwitchBox.
 */
public class VectorSwitch extends GenericVectorFunction implements Serializable {
  
  protected int selectedInput;
  
  /** Creates a default VectorSwitch with two inputs. */
  public VectorSwitch() {
    super(2, 1, 1);
  }
  
  /** computes new values for output vector.
   *
   */
  protected void compute() {
    outputValues[0] = inputValues[selectedInput];
  }
  
  /**
   * Gets index of input that is routed to the output.
   */
  public int getSelectedInput() {
    return this.selectedInput;
  }
  
  /**
   * Sets index of input that is routed to the output.
   */
  public void setSelectedInput(int selectedInput) {
    this.selectedInput = selectedInput;
    trigger();
  }
  
  /**
   * Computes output vectors and informs listeners.<br>
   * Sends selected input value even if the other values are null.
   */
  public void trigger() {
    // check whether the selected input value is set already
    if  ((selectedInput >= inputValues.length) || (inputValues[selectedInput] == null)) {
      return;
    }
    
    // create (single!) dynamically sized output vector
    if  (outputLength[0] < 0) {
      int newSize = inputValues[-outputLength[0]-1].getDimension();
      outputValues[0] = new DVector(newSize);
    }
    
    compute();  // compute new output values
    fireVectorEvent(new VectorEvent(this, outputValues)); // inform listeners
  }
  
}
