package physbeans.inout;

import java.awt.*;
import javax.swing.*;
import java.util.*;

/**
 * Simple Physics Applet, base class of all templates.<br>
 * Sets locale using HTML parameters or defaults and sets the standard font.<br>
 * PhysBeansApplet provides a framework to run applets as applications as well.
 * A child applet <code>Child</code> has to define a main consisting of the line<br>
 *    <code>startApp(new Child(), 540, 580);</code>
 */
public class PhysBeansApplet extends JApplet {
  
  protected Locale currentLocale;
  //protected Font standardFont = new java.awt.Font("Lucida Sans", Font.PLAIN, 11);
  protected Font standardFont = new java.awt.Font("DejaVu Sans", Font.PLAIN, 11);

  protected void setLocale() {
    try {
      String language = getParameter("Language");
      String country = getParameter("Country");
      if (language == null) {
        currentLocale = Locale.getDefault();
      } else if (country == null) {
        currentLocale = new Locale(language);
      } else {
        currentLocale = new Locale(language, country);
      }
    } catch (Exception e) {
      // running as application
      currentLocale = Locale.getDefault();
    }
  }
  
  /**
   * Starts the given applet as an application in a frame of width w and
   * height h.
   */
  public static void startApp(PhysBeansApplet app, int w, int h) {
    String title = app.getClass().toString();
    if (title.indexOf("class") != -1) {
      title = title.substring(6);
    }
    
    JFrame frame = new JFrame(title);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    
    Container p = frame.getContentPane();
    p.add(app);
    
    frame.setSize(w+8, h+25); // correcting for standard frame border
    app.init();
    app.start();
    frame.setVisible(true);
  }
}
