package physbeans.inout;

import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.io.*;

/** basic panel for PhysicsApplet.<br>
 * used for input, object and output panel <br>
 */
public class PhysicsPanel extends JPanel implements Serializable {
  
  /** if true the standard border is attached */
  protected boolean bordered;
  
  public PhysicsPanel() {
    super();
    
    // gets font and background color from container
    setFont(null);
    setOpaque(false);
    
    // minimum size is provided to make components visible in any layout
    // otherwise they could shrink to nothing
    setMinimumSize(new Dimension(50,50));
    
    // preferred size is calculated automatically (by size of components)
    // or set by descendants if necessary
    
    // huge maximum size guarantees that all useful space is consumed
    // otherwise one gets blank space at the end of a Box
    setMaximumSize(new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE));
  }
  
  /**
   * gets value of bordered flag.<br>
   * if true the standard border is attached
   */
  public boolean isBordered() {
    return this.bordered;
  }
  
  /**
   * sets value of bordered flag.<br>
   * if true the standard border is attached
   */
  public void setBordered(boolean bordered) {
    this.bordered = bordered;
    if (bordered) {
      Border emptyBorder = BorderFactory.createEmptyBorder(4,4,4,4);
      Border etchBorder = BorderFactory.createEtchedBorder();
      setBorder(BorderFactory.createCompoundBorder(etchBorder, emptyBorder));
    } else {
      setBorder(null);      
    }
    repaint();
  }
 
}
