package physbeans.math;

import physbeans.model.*;

/**
 * Base class of one-dimensional interpolation functions.
 */
abstract public class Interpolator1D {
  
  /**
   * Points containing the values.
   */
  protected Point2dVector points;
  
  /** Creates a new instance of Interpolator1D */
  public Interpolator1D(Point2dVector points) {
    this.points = points;
  }
  
  abstract public double evaluate(double t);
  
  /**
   * Checks if x values are sorted in increasing order.
   */
  protected void checkOrder() {
    for ( int i = 1; i < points.size(); i++ ) {
      if ( points.getX(i - 1) >= points.getX(i) )
        throw new IllegalArgumentException
            ( "Points must be sorted in increasing x value");
    }    
  }
  
  /**
   * Finds the index i with x_0 <= x < x_i+1.
   * Returns -1 for x < xmin, size-1 for x > xMax,
   *    size-2 for x approx. xMax (to handle right edge properly)
   */
  protected int findIndex(double x) {
    for (int i = 0; i < points.size(); i++) {
      if (x < points.getX(i)) {
        return i-1;
      }
    }
    
    // check if x == lastPoint.x, allowing for rounding error
    if (Maths.isEqual(x, points.getX(points.size()-1))) {
      return points.size()-2;
    }
    return points.size()-1;
  }
}
