package physbeans.math;

import static java.lang.Math.*;     // readable math at last!

/**
 * Twodimensional ray, usually given by a point and an angle against the
 * positive x axis.
 */
public class Ray2D {
  
  protected DVector p;
  protected double alpha;
  
  /** Creates a new ray with start point p and angle alpha */
  public Ray2D(DVector p, double alpha) {
    this.p = p;
    this.alpha = alpha;
  }
  
  /**
   * Gets the point on the ray that is given by the parameter value l where the
   * ray is described by<br>
   *   x = p + l*( cos(alpha), sin(alpha) )
   */
  public DVector getPointAtParameter(double l) {
    double xh = p.x() + l*cos(alpha);
    double yh = p.y() + l*sin(alpha);
    return new DVector(xh, yh);
  }
  
  /**
   * Gets the start point of the ray.
   */
  public DVector getStartPoint() {
    return p;
  }
  
  /**
   * Gets the angle of the ray measured against the positive x axis.
   */
  public double getAngle() {
    return alpha;
  }
}
