package physbeans.model;

/**
 * Range of indices for access to a vector or matrix, given by a start,
 * an end and a stride value.
 */
public class IndexRange {

  protected int start,  end,  stride;

  /**
   * Creates an index range with given start, end and stride values.
   * The start and end values have to be nonnegative, stride nonzero.
   */
  public IndexRange(int start, int stride, int end) {
    if (start >= 0) {
      this.start = start;
    } else {
      throw new IndexOutOfBoundsException();
    }

    if (stride != 0) {
      this.stride = stride;
    } else {
      throw new IndexOutOfBoundsException();
    }

    if (end >= 0) {
      this.end = end;
    } else {
      throw new IndexOutOfBoundsException();
    }
  }

  /**
   * Creates an index range with given start and end values and a stride of 1.
   */
  public IndexRange(int start, int end) {
    this(start, 1, end);
  }

  /**
   * Gets the start value.
   */
  public int getStart() {
    return start;
  }

  /**
   * Gets the end value.
   */
  public int getEnd() {
    return end;
  }

  /**
   * Gets the stride value.
   */
  public int getStride() {
    return stride;
  }

  /**
   * Gets number of index values.
   */
  public int getSize() {
    if (start > end && stride > 0) {
      return 0;
    }
    if (start < end && stride < 0) {
      return 0;
    }

    return 1 + (end - start)/stride;
  }

  /**
   * Returns an IndexRange shifted by an offset.
   */
  public IndexRange add(int offset) {
    return new IndexRange(start + offset, stride, end + offset);
  }
}
