package physbeans.model;

import physbeans.math.*;
import physbeans.event.*;

/**
 * base class of vector fields
 */
abstract public class VectorField extends ScalarField {
  
  protected int vDim;
  protected DVector vSent;
  
  /**
   * create vector field with 2 vectors in 2 space dimensions
   */
  public VectorField() {
    this(2, 2);
  }
  
  /**
   * create vector field with vDim vectors in 2 space dimensions
   */
  public VectorField(int vDim) {
    this(2, vDim);
  }
  
  /**
   * create vector field with vDim vectors in dim space dimensions
   */
  public VectorField(int dim, int vDim) {
    super(dim);
    this.vDim = vDim;
    vSent = new DVector(0);
  }
  
  /**
   * get vector value at given coordinates
   */
  abstract public DVector getVectorValue(DVector param);
  
  /**
   * return the absolute value at the given coordinates.<br>
   * This is a simple way to associate a scalar field  with the vector field.
   */
  public double getScalarValue(DVector v) {
    return getVectorValue(v).norm();
  }
  
  /**
   * return the vector dimension
   */
  public int getVectorDimension() {
    return vDim;
  }
  
  /**
   * set the dimension of the vectors
   */
  public void setVectorDimension(int vDim) {
    this.vDim = vDim;
  }

  /**
   * sends Vector event with vector field value at a given position
   */
  public void sendVectorValue(DVector coord) {
    vSent = getVectorValue(coord);
    fireVectorEvent(new VectorEvent(this, vSent));
  }
  
  /**
   * Gets vector value at position of last send request.
   */
  public DVector getLastVectorValue() {
    return vSent;
  }
}
