package physbeans.phys;

/**
 * Twodimensional potential function, constant inside a rectangular box,
 * zero outside. 
 */
public class Box2DPotential extends Schroedinger2DPotential {

  protected double V0;
  protected double dx, dy, posx, posy;

  public Box2DPotential() {
    super();
    V0 = 4e-20;
    posx = 1.6e-9;
    posy = 0.0;
    dx = 8e-10;
    dy = 4e-10;
  }

  public double getScalarValue(double x, double y) {
    if ((x > posx - dx / 2) && (x < posx + dx / 2) && (y > posy - dy / 2) &&
            (y < posy + dy / 2)) {
      return V0;
    } else {
      return 0.0;
    }
  }

  /**
   * Sets the constant value of the potential.
   */
  public void setV0(double V0) {
    this.V0 = V0;
    computeGrid();
    if (field != null) {
      field.computeCachedMatrices();
    }
    trigger();
  }

  /**
   * Gets the constant value of the potential.
   */
  public double getV0() {
    return V0;
  }

  /**
   * Sets the width of the box in x direction.
   */
  public void setWidthX(double dx) {
    this.dx = dx;
    computeGrid();
    if (field != null) {
      field.computeCachedMatrices();
    }
    trigger();
  }

  /**
   * Gets the width of the box in x direction.
   */
  public double getWidthX() {
    return dx;
  }

  /**
   * Sets the width of the box in y direction.
   */
  public void setWidthY(double dy) {
    this.dy = dy;
    computeGrid();
    if (field != null) {
      field.computeCachedMatrices();
    }
    trigger();
  }

  /**
   * Gets the width of the box in y direction.
   */
  public double getWidthY() {
    return dy;
  }

  /**
   * Sets the x coordinate of the box center.
   */
  public void setPosX(double posx) {
    this.posx = posx;
    computeGrid();
    if (field != null) {
      field.computeCachedMatrices();
    }
    trigger();
  }

  /**
   * Gets the x coordinate of the box center.
   */
  public double getPosX() {
    return posx;
  }

  /**
   * Sets the y coordinate of the box center.
   */
  public void setPosY(double posy) {
    this.posy = posy;
    computeGrid();
    if (field != null) {
      field.computeCachedMatrices();
    }
    trigger();
  }

  /**
   * Gets the y coordinate of the box center.
   */
  public double getPosY() {
    return posy;
  }
}
