package physbeans.phys;

import physbeans.func.*;
import physbeans.math.*;

/**
 * A physical bean describing  an n-dimensional linear oscillator with friction
 * and external forces given by<br>
 *    M x'' + B x' + C x = F(t)<br>
 * where position x and force F are n-dimensional vectors and M, B, C are
 * symmetric nxn matrices defining the masses, dampers and springs.
 */
public class CoupledSprings extends GenericCoupledSprings {
  
  /**
   * Creates three-dimensional standard CoupledSprings.
   */
  public CoupledSprings() {
    super();
  }
  
  /**
   * Sets mass matrix m.
   */
  public void setM(Matrix m) {
    this.m = m;
    adaptSize(m);
  }
  
  /**
   * Sets stiffness matrix c.
   */
  public void setC(Matrix c) {
    this.c = c;
    adaptSize(c);
  }
  
  /**
   * Sets viscous damping matrix b.
   */
  public void setB(Matrix b) {
    this.b = b;
    adaptSize(b);
  }

  /**
   * Adapts vector size of internal data to the size of the matrix a.
   * Restarts the system in any case.
   */
  protected void adaptSize(Matrix a) {
    if (a.getRowDimension() != getInitialValues().getDimension() / 2) {
      setInitialValues(new DVector(2 * a.getRowDimension()));
    } else {
      restartNow();
    }
  }
}
