package physbeans.phys;

import physbeans.model.*;
import physbeans.math.*;
import physbeans.func.*;

/**
 * VectorField that is defined by an array of strings that are parsed using
 * variables names x1, x2, ... xn.<p>
 * For details about the parser
 * @see physbeans.func.ParsedFunction
 */
public class ParsedVectorField extends VectorField {
  
  protected ParsedFunction parseFunc;
  
  /** Creates a new instance of ParsedVectorField */
  public ParsedVectorField() {
    super();
    
    parseFunc = new ParsedFunction();
    defineVariables();
  }
  
  /**
   * Gets vector value at given coordinates coord.
   */
  public DVector getVectorValue(DVector coord) {
    parseFunc.setInputVector(coord);
    return parseFunc.getOutputVector();
  }
  
  /**
   * Gets description strings of all functions.
   */
  public String[] getFunction() {
    return parseFunc.getFunction();
  }
  
  /**
   * Sets description strings of all functions.
   */
  public void setFunction(String[] function) {
    parseFunc.setFunction(function) ;
    super.setVectorDimension(function.length);
  }
  
  /**
   * Sets the number of space dimensions of the field.
   */
  public void setSpaceDimension(int dim) {
    super.setSpaceDimension(dim);
    defineVariables();
  }
  
  /**
   * Sets the number of vector elements.<p>
   * Defines dummy strings for the parser functions.
   */
  public void setVectorDimension(int vDim) {
    String[] funcs = new String[vDim];
    for (int i = 0; i < vDim; i++) {
      funcs[i] = "x1";
    }
    setFunction(funcs);
  }
  
  /**
   * Defines the variable names x1, x2, ...xn, that are used for parsing the
   * strings.
   */
  protected void defineVariables() {
    int nVars = getSpaceDimension();
    String[] vars = new String[nVars];
    
    for (int i = 1; i <= nVars; i++) {
      vars[i-1] = "x" + i;
    }
    
    parseFunc.setVariableName(vars);
  }
}
