package physbeans.views;

import java.awt.*;
import java.awt.image.*;

/**
 * A simple color table of length 256, for 3x8 bit RGB.<br>
 * The default color table runs linearly from black over blue to magenta to
 * white to yellow to red to black.
 */
public class ColorTable {
  protected IndexColorModel table;
  byte[] r, g, b, a;
  
  /**
   * default color table<br>
   * it runs linearly from black over blue to magenta to white
   *  to yellow to red to black
   */
  public ColorTable() {
    initTables();
    defineRGBAValues();
    createTable();
  }
  
  protected void initTables() {
    r = new byte[256];
    g = new byte[256];
    b = new byte[256];
    a = new byte[256];
    for (int i=0; i<256; i++) {
      a[i] = (byte) 255;
    }
  }
  
  protected void createTable() {
    table = new IndexColorModel(8, r.length, r, g, b, a);
  }
  /**
   * creates a new colortable using the r/g/b arrays
   */
  public IndexColorModel getTable() {
    return table;
  }
  
  /**
   * Gets color for given index.
   */
  public Color getColor(int i) {
    return new Color(table.getRGB(i));
  }
  
  /**
   * Define 256 r, g, b values for the color table.<br>
   * Optionally the alpha channel can be changed from its default value 255.
   */
  protected void defineRGBAValues() {
    int i;
    for (i = 0; i < 42; i++) {
      r[i] = (byte) 0;
      g[i] = (byte) 0;
      b[i] = (byte) ((255 * i) / 42);
    }
    for (i = 42; i < 85; i++) {
      r[i] = (byte) 0;
      g[i] = (byte) ((255 * (i - 42)) / 43);
      b[i] = (byte) 255;
    }
    for (i = 85; i < 128; i++) {
      r[i] = (byte) ((255 * (i - 85)) / 43);
      g[i] = (byte) 255;
      b[i] = (byte) 255;
    }
    for (i = 128; i < 171; i++) {
      r[i] = (byte) 255;
      g[i] = (byte) 255;
      b[i] = (byte) ((255 * (171 - i)) / 43);
    }
    for (i = 171; i < 214; i++) {
      r[i] = (byte) 255;
      g[i] = (byte) ((255 * (214 - i)) / 43);
      b[i] = (byte) 0;
    }
    for (i = 214; i < 256; i++) {
      r[i] = (byte) ((255 * (256 - i)) / 42);
      g[i] = (byte) 0;
      b[i] = (byte) 0;
    }
  }
}
