package physbeans.views;

import physbeans.model.*;
import java.awt.*;

/**
 * View that displays a TimedDataBuffer as a number of graphs, each in its own
 * color.<br>
 * When the buffer spills over cyclically, the time bounds are adapted so that
 * the buffer is displayed through several sweeps.<br>
 * The plots can be line or point plots.
 */
public class TimedDataBufferView extends DataBufferView {
  
  /** Creates a new instance of TimedDataBufferView */
  public TimedDataBufferView() {
    super();
  }
  
  /**
   * Sets underlying model, i.e. the DataBuffer defining the points.
   */
  public void setModel(DataBuffer m) {
    model = m;
    
    int nLinesNew = model.getNBuffer() - 1;
    if (nLinesNew != lineActive.length) {
      lineActive = new boolean[nLinesNew];
      lineActive[0] = true;
    }
    
    if (model.getNData() < 2) {   // after (re-)start (n=0) or overflow (n=1)
      adaptTimeLimits();
    }
    update();
  }
  
  /**
   * Change lower and upper time boundaries according to number of sweeps.
   */
  public void adaptTimeLimits() {
    double timeInterval =
        ((TimedDataBuffer) model).getTimePerTick()*model.getSize();
    int nSweeps = (int) Math.round(getStartTime()/timeInterval);
    if (model.getNData() == 0) {
      nSweeps = 0;   // has to be set explicitely because the buffer is not at 0
                     // after restart and before play
    }
    
    trafo.setMinX(nSweeps*timeInterval);
    trafo.setMaxX((nSweeps + 1)*timeInterval);
  }
  
  /**
   * Gets time of first data element.
   */
  protected double getStartTime() {
    return model.getData(0).get(0);
  }
}
